# -*- coding: utf-8 -*-

class O365ObjectTypeEnum(object):

    """Implementation of the 'o365ObjectType' enum.

    TODO: type enum description here.

    Attributes:
        KDOMAIN: TODO: type description here.
        KOUTLOOK: TODO: type description here.
        KMAILBOX: TODO: type description here.
        KUSERS: TODO: type description here.
        KGROUPS: TODO: type description here.
        KSITES: TODO: type description here.
        KUSER: TODO: type description here.
        KGROUP: TODO: type description here.
        KSITE: TODO: type description here.
        KAPPLICATION: TODO: type description here.
        KGRAPHUSER: TODO: type description here.
        KPUBLICFOLDERS: TODO: type description here.
        KPUBLICFOLDER: TODO: type description here.
        KTEAMS: TODO: type description here.
        KTEAM: TODO: type description here.

    """

    KDOMAIN = 'kDomain'

    KOUTLOOK = 'kOutlook'

    KMAILBOX = 'kMailbox'

    KUSERS = 'kUsers'

    KGROUPS = 'kGroups'

    KSITES = 'kSites'

    KUSER = 'kUser'

    KGROUP = 'kGroup'

    KSITE = 'kSite'

    KAPPLICATION = 'kApplication'

    KGRAPHUSER = 'kGraphUser'

    KPUBLICFOLDERS = 'kPublicFolders'

    KPUBLICFOLDER = 'kPublicFolder'

    KTEAMS = 'kTeams'

    KTEAM = 'kTeam'

